==> haskell-monadrandom-0.5.2-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadrandom.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MonadRandom
version:              0.5.2
visibility:           public
id:                   MonadRandom-0.5.2-lYkHHKe4KDBV6nNwZ9xQ2
key:                  MonadRandom-0.5.2-lYkHHKe4KDBV6nNwZ9xQ2
license:              BSD-3-Clause
maintainer:           Brent Yorgey <byorgey@gmail.com>
author:               Cale Gibbard and others
synopsis:             Random-number generation monad.
description:          Support for computations which consume random values.
category:             Control
abi:                  a40c28fa7717170600db653a9ffe35a8
exposed:              True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict

import-dirs:          /usr/lib/ghc-8.10.1/site-local/MonadRandom-0.5.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/MonadRandom-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/MonadRandom-0.5.2
hs-libraries:         HSMonadRandom-0.5.2-lYkHHKe4KDBV6nNwZ9xQ2
depends:
    base-4.14.0.0 mtl-2.2.2 primitive-0.7.1.0-IFi6E3ujuHzGpMfr4UimtV
    random-1.1-AA3zCuOgsVZCzsZYE3CMpY transformers-0.5.6.2
    transformers-compat-0.6.5-5FpQwDSHwAD8xLwpEoaQi

haddock-interfaces:   /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html:         /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monadrandom-0.5.2-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadrandom.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MonadRandom
version:              0.5.2
visibility:           public
id:                   MonadRandom-0.5.2-60SoXXsV0Ee9vALivlsEOx
key:                  MonadRandom-0.5.2-60SoXXsV0Ee9vALivlsEOx
license:              BSD-3-Clause
maintainer:           Brent Yorgey <byorgey@gmail.com>
author:               Cale Gibbard and others
synopsis:             Random-number generation monad.
description:          Support for computations which consume random values.
category:             Control
abi:                  f09492a75a7b3a7c637cbed296ae5204
exposed:              True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict

import-dirs:          /usr/lib/ghc-8.10.2/site-local/MonadRandom-0.5.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/MonadRandom-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/MonadRandom-0.5.2
hs-libraries:         HSMonadRandom-0.5.2-60SoXXsV0Ee9vALivlsEOx
depends:
    base-4.14.1.0 mtl-2.2.2 primitive-0.7.1.0-Dh5KikZUo47KKNL1rHRtD4
    random-1.1-IcUwfYF3CGOHS82o6ktbLi transformers-0.5.6.2
    transformers-compat-0.6.5-E9Rid1zC4al974cN3f5HFc

haddock-interfaces:   /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html:         /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
